#
# spec file for package transactional-update
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           transactional-update
Version:        2.2
Release:        lp150.1.1
Summary:        Transactional Updates with btrfs and snapshots
License:        GPL-2.0-or-later
Group:          System/Base
URL:            https://github.com/thkukuk/transactional-update
Source:         %{name}-%{version}.tar.bz2
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  rpm-devel
BuildRequires:  suse-module-tools
BuildRequires:  pkgconfig(libzypp)
Requires:       logrotate
Requires:       lsof
# psmisc is needed because of fuser
Requires:       perl-HTML-Parser
Requires:       psmisc
Requires:       rsync
Conflicts:      snapper-zypp-plugin
Recommends:     rebootmgr

%description
transactional-update is a tool to update a system in an atomic
way with zypper, btrfs and snapshots.

%prep
%setup -q

%build
%configure
make %{?_smp_mflags}

%install
%make_install
%fdupes %{buildroot}%{_mandir}

%pre
%service_add_pre %{name}.service %{name}.timer create-dirs-from-rpmdb.service

%post
%service_add_post %{name}.service %{name}.timer create-dirs-from-rpmdb.service
%regenerate_initrd_post

%posttrans
%regenerate_initrd_posttrans

%preun
%service_del_preun %{name}.service %{name}.timer create-dirs-from-rpmdb.service

%postun
%service_del_postun %{name}.service %{name}.timer create-dirs-from-rpmdb.service
%regenerate_initrd_post

%files
%license COPYING
%doc NEWS
%config(noreplace) %{_sysconfdir}/logrotate.d/transactional-update
%{_unitdir}/transactional-update.service
%{_unitdir}/transactional-update.timer
%{_unitdir}/create-dirs-from-rpmdb.service
%{_sbindir}/create_dirs_from_rpmdb
%{_sbindir}/transactional-update
%{_sbindir}/tu-rebuild-kdump-initrd
%{_sbindir}/transactional-update-helper
%dir %{_prefix}%{_sysconfdir}
%{_prefix}%{_sysconfdir}/transactional-update.conf
%dir %{_prefix}/lib/dracut
%dir %{_prefix}/lib/dracut/modules.d
%{_prefix}/lib/dracut/modules.d/50transactional-update/
%{_mandir}/man5/transactional-update.conf.5%{?ext_man}
%{_mandir}/man8/transactional-update.8%{?ext_man}
%{_mandir}/man8/transactional-update.timer.8%{?ext_man}
%{_mandir}/man8/transactional-update.service.8%{?ext_man}

%changelog
* Wed May  2 2018 iforster@suse.com
- Update to version 2.2
  - Fix security issue in self update [boo#1091316]
  - Create dirs in /var more reliably by sorting the list
- Rebuild initrd (needed since 2.0)
* Thu Apr 26 2018 kukuk@suse.de
- Update to version 2.1
  - Cleanup the code cleaning up /etc
* Tue Apr 24 2018 kukuk@suse.de
- Update to version 2.0
  - Create missing directories from rpm database during boot
  - Merge /etc overlay with root subvolume during update
* Fri Apr 20 2018 kukuk@suse.de
- Update to version 1.29
  - Implement self-update
  - Disable optical media on dup
  - Ignore certain zypper return codes
* Tue Apr  3 2018 rbrown@suse.com
- Add conflicts with snapper-zypp-plugin
* Sat Mar 17 2018 rbrown@suse.com
- Require perl-HTML-Parser (needed since 1.26) [boo#1085764]
* Mon Mar 12 2018 kukuk@suse.de
- Update to version 1.28
  - Adjust for latest grub2
* Tue Mar  6 2018 kukuk@suse.de
- Update to version 1.27
  - Fallback to snapper without dbus support if dbus fails
  - Add workaround for update-alternatives
  - Add support for /usr/etc/transactional-update.conf
* Fri Feb 23 2018 kukuk@suse.com
- Use %%license instead of %%doc [bsc#1082318]
* Wed Jan 31 2018 kukuk@suse.de
- Update to version 1.26
  - Auto accept repo keys config option
  - Detect broken snapshots after abort
  - Ignore user deleted snapshots
  - Include all error messages in main log file
  - Add configuration file
  - Correctly implement migration of major OS versions
  - Default reboot strategy is configuration option
  - Salt option is deprecated
* Tue Jan  9 2018 kukuk@suse.de
- Update to version 1.25
  - preliminary SELinux support
  - support for seperate /var subvolume
* Tue Dec  5 2017 kukuk@suse.de
- Update to version 1.24
  - Don't save unused snapshots if we may delete them again.
    Partly fixes [bsc#1071038]
  - Copy passwd, group and shadow to /usr/etc if modified
* Fri Nov 17 2017 kukuk@suse.de
- Update to version 1.23
  - Fix re-registration in rollback case
  - Fix problems with updating the grub2 bootloader
  - Add support for migration of products with SCC/SMT
  - Re-add support to re-write bootloader
  [bsc#1068933]
* Tue Nov  7 2017 kukuk@suse.de
- Update to version 1.22
  - Rewrite cleanup code to be more aggressive
* Fri Oct 27 2017 kukuk@suse.de
- Update to version 1.21
  - Reset salt grains even if no update was found
* Wed Sep 13 2017 kukuk@suse.de
- Update to version 1.20
  - Improve documentation
  - Add pkg update option
* Fri Jun 30 2017 kukuk@suse.de
- Update to version 1.19
  - Add 'shell' option for debugging and testing
* Wed Jun 28 2017 kukuk@suse.de
- Update to version 1.18
  - Auto accept product license in non-interactive mode
* Tue Jun 27 2017 kukuk@suse.de
- Update to version 1.17
  - copy modified bootloader config into snapshot
  - unit file cleanup, no change of behavior
* Mon Jun 26 2017 kukuk@suse.de
- Update to version 1.16
  - internal changes [bsc#1045942]
* Thu Jun  1 2017 kukuk@suse.de
- Update to version 1.15
  - Rename option ptf to pkg
  - Add option to set salt grains
* Fri Apr 21 2017 kukuk@suse.de
- Update to version 1.14
  - Fix check of return values of commands in pipes [bsc#1034900]
* Tue Mar 21 2017 kukuk@suse.de
- Update to version 1.12
  - minor bug fixes
* Thu Mar  2 2017 kukuk@suse.de
- Update to version 1.11
  - use --no-allow-vendor-change with "zypper dup"
  - update manual page
* Mon Feb 13 2017 kukuk@suse.de
- Update to version 1.10
  - implement and document rollback option
* Tue Feb  7 2017 kukuk@suse.de
- Update to version 1.9
  - fix umounting of special filesystems and subvolumes
  - fix interactive installation of PTFs [bsc#1023026]
  - fix dependencies of systemd service
* Wed Feb  1 2017 kukuk@suse.de
- Add Requires for lsof and fuser
* Wed Feb  1 2017 kukuk@suse.de
- Update to version 1.8
  - fix references in html docu
  - build kdump initrd if we build standard initrd, too
* Mon Jan 30 2017 kukuk@suse.de
- Update to version 1.7
  - build html docu, too
* Sun Jan 29 2017 kukuk@suse.de
- Update to version 1.6
  - Add support for kdump [bsc#1018098]
* Thu Jan 19 2017 kukuk@suse.de
- Update to version 1.5
  - Install PTFs in interactive mode
  - Sync state file between current and new snapshot
* Tue Jan 17 2017 kukuk@suse.de
- Update to version 1.4
  - Fix wrong error messages
  - More debug output if umount fails
  - Try a second time if umount fails
* Mon Dec 19 2016 kukuk@suse.de
- Update to version 1.3
  - Add initrd option
* Thu Dec 15 2016 kukuk@suse.de
- Do some spec file cleanup
* Mon Dec 12 2016 kukuk@suse.de
- Update to version 1.2
  - suppport ro-subvolume with overlayfs
* Tue Dec  6 2016 kukuk@suse.de
- Update to version 1.1
  - bug fix release
  - implement lock
* Wed Nov 23 2016 kukuk@suse.de
- Update to version 1.0
  - implement and document PTF options
* Mon Nov 21 2016 kukuk@suse.de
- Update to version 0.99
  - Support for rebootmgr
  - Write real manual page
* Mon Nov 21 2016 kukuk@suse.de
- Add empty directory
  /etc/systemd/system/transactional-update.timer.d/
  so to make it easier to override transactional-update.timer
  entries.
* Thu Nov 17 2016 kukuk@suse.de
- Update to version 0.90
  - Finish normal options
  - Implement support for PTFs
* Sun Nov  6 2016 kukuk@suse.com
- Disable restart on update for post install scripts
* Sun Nov  6 2016 kukuk@suse.de
- Implement activating the new snapshot as new root filesystem
* Fri Nov  4 2016 kukuk@suse.de
- Initial version
